TXPlayInfoParams class

Constructors

TXPlayInfoParams({required int? appId, required String? fileId, String? psign = "", String? url = "", Map<String, String>? httpHeader, int encryptedMp4Level = TXVodPlayEvent.MP4_ENCRYPTION_LEVEL_NONE})
const
TXPlayInfoParams.useFileId({required int? appId, required String? fileId, String? psign = "", Map<String, String>? httpHeader, int encryptedMp4Level = TXVodPlayEvent.MP4_ENCRYPTION_LEVEL_NONE})
const
TXPlayInfoParams.useUrl({required String? url, Map<String, String>? httpHeader, int encryptedMp4Level = TXVodPlayEvent.MP4_ENCRYPTION_LEVEL_NONE})
const

Properties

appId int?
final
encryptedMp4Level int
final
fileId String?
final
hashCode int
The hash code for this object.
no setterinherited
httpHeader Map<String, String>?
final
psign String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited