TXVodDownloadMediaInfo class

Video download information. 视频下载信息

Constructors

TXVodDownloadMediaInfo()

Properties

dataSource TXVodDownloadDataSource?
File ID storage fileId 存储
getter/setter pair
downloadSize int?
Downloaded size, in bytes. 已下载大小,单位:byte
getter/setter pair
downloadState int?
Download status. 下载状态
getter/setter pair
duration int?
Total duration. 总时长
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isResourceBroken bool?
Whether the resource is damaged, such as being deleted. 资源是否已损坏, 如:资源被删除了
getter/setter pair
playableDuration int?
Downloaded playable duration 已下载的可播放时长
getter/setter pair
playPath String?
Cache address. 缓存地址
getter/setter pair
progress double?
Download progress. 下载进度
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
Total file size, in bytes. 文件总大小,单位:byte
getter/setter pair
speed int?
Download speed, in KBytes/second. 下载速度,单位:KByte/秒
getter/setter pair
url String?
Video URL to be downloaded, required for URL download. 需要下载的视频url,url下载必填
getter/setter pair
userName String?
Account name, used to set the account name for URL download. It is not recommended to set a string that is too long, Otherwise, it may lead to unforeseen problems. 账户名称,用于url下载设置账户名称。不建议设置比较长的字符串,否则可能会导致不可预料的问题。
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toMsg() TXVodDownloadMediaMsg
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited